@@ -16,7 +16,7 @@ class ShowingProgress(object):
             process(something)
     '''
     def __init__(self, iterable, message='Item #{} done. Working...',
-                 seconds=6, done='Finished!'):
+                 seconds=6, done='Done in {time}! Total items: {total}'):
         self.iterable = iterable
         self.seconds = timedelta(0, seconds)
         self.message = message
@@ -25,15 +25,16 @@ class ShowingProgress(object):
     def __iter__(self):
         utcnow = datetime.utcnow
         seconds = self.seconds
-        printed = utcnow()
-        for i, o in enumerate(self.iterable, 1):  # Start counting at 1
-            yield i, o
+        started = printed = utcnow()
+        for index, o in enumerate(self.iterable, 1):  # Start counting at 1
+            yield index, o
 
             if seconds > utcnow() - printed:
                 continue
-            print(self.message.format(i))
+            print(self.message.format(index))
             printed = utcnow()
-        print(self.done)
+        if self.done:
+            print(self.done.format(total=index, time=utcnow() - started))
 
 
 class PercentageDone(object):
@@ -68,8 +69,7 @@ class PercentageDone(object):
         if percent > self.current:
             self.current = percent
             self.delta = datetime.utcnow() - self.start
-            self.estimate = timedelta(0,
-                100 * self.delta.seconds / percent)
+            self.estimate = timedelta(0, 100 * self.delta.seconds / percent)
             self.remaining = self.estimate - self.delta
             if self.remaining < timedelta(0):
                 self.remaining = timedelta(0)
